/*
  RISC OS KWin client

  Copyright 2004
   Carsten Clever <clushkou@gmx.net>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  Boston, MA 02110-1301, USA.
*/

#ifndef RISC_OS_ABOVE_BUTTON_H
#define RISC_OS_ABOVE_BUTTON_H

#include "Button.h"
//Added by qt3to4:
#include <QMouseEvent>

namespace RiscOS
{

class AboveButton : public Button
{
   Q_OBJECT

   public:

      AboveButton(QWidget *parent);

   signals:

      void above();

   protected:

      void mouseReleaseEvent(QMouseEvent*);
};

} // End namespace

#endif
